@@ -14,8 +14,8 @@ use Sys::Hostname;
 use Sys::Syslog;
 use Errorlog::TeeOutput;
 
-my $version = '$Id: Errorlog.pm 40915 2014-01-30 11:53:50Z anton $ ';
-our $VERSION = "1.35";
+my $version = '$Id: Errorlog.pm 41392 2014-04-23 14:22:52Z anton $ ';
+our $VERSION = "1.38";
 
 #global variable, needed for TeeOutput
 our $SELF;
@@ -100,6 +100,7 @@ sub new {
 			'autoconfess' => 1,
 			'skipEND' => '',
 			'noDebug2Syslog' => 1,
+			'filePermissions' => 0660,
 		}
 		);
 
@@ -123,7 +124,16 @@ sub new {
 	my @params = ();
 	my %params;
 	my $syslogSuppressed = '';
+	$logdir = $self->field('logdir');
+	$logfile = $self->field('logfile');
 
+	if ($self->{outputmodes}->{syslog}) {
+		if (openlog($0, 'cons,pid', $self->{fields}->{facility}) ) {
+			$params{'syslog'} = 1; 
+		} else {
+			$self->error("Could not open syslog");
+		}
+	}
 
 	if ($self->{fields}->{noDebug2Syslog}) {
 		if ($Baseobject::verbosity >= 2) {
@@ -133,34 +143,27 @@ sub new {
 				$self->{outputmodes}->{logfile} = 1;
 				syslog('debug', $syslogSuppressed);
 				$self->{outputmodes}->{syslog} = 0;
-#				closelog();
+				closelog();
 			}
 		}
 	}
 
-	if ($self->{outputmodes}->{syslog}) {
-		if (openlog($0, 'cons,pid', $self->{fields}->{facility}) ) {
-			$params{'syslog'} = 1; #1 is dummy value
-		} else {
-			$self->error("Could not open syslog");
-		}
-	}
 
 	if ($self->{outputmodes}->{logfile}) {
-		$logdir = $self->field('logdir');
-		$logfile = $self->field('logfile');
-
 		my $file = "$logdir/$logfile";
+		my $filePermissions = $self->field('filePermissions');
+
+		#test if we can write here before tie fails on it
 		unless (-w $file) {
-			#test if we can write here before tie fails on it
-			my $fh = new FileHandle();
-			unless (open ($fh,">utf8", $file)) {
-				carp "WARNING: Could not open file: $file, $!\nWARNING  No logging to logfile will occur. Output to stderr forced";
+			my $fh = new IO::File($file, O_WRONLY|O_CREAT|O_APPEND, $filePermissions);
+			unless ($fh) {
+				carp "WARNING: Could not open file: $file, $!. No logging to logfile will occur. Output to stderr forced";
 				# make sure stderr is not lost
 				$self->{outputmodes}->{stderr} = 1;
 				$self->{outputmodes}->{logfile} = 0;
+				$fh->write("blah");
 			} else {
-				close($fh);
+				$fh->close;
 			}
 		}
 	}
@@ -177,7 +180,6 @@ sub new {
 		push (@params, ">>$logfile");
 	}
 
-	#do this for now, must think about it some more
 	$self->{outputmodes}->{logbuffer} = 1 if $self->{fields}->{mailonfailure};
 
 	if ($self->{outputmodes}->{logbuffer})	{
@@ -558,25 +560,6 @@ sub uniquelist {
 	return [keys (%hash)];
 }
 
-
-# overloaden van Baseobject::debug
-sub debug {
-	my $self = shift;
-	if (verbosity() >= 2) {
-		my ($package, $file, $line) = caller;
-		foreach my $el (@_) {
-			my $location = '';
-			$location = " at $file line $line" unless $el =~ /\n$/;
-			my $savedLogLevel = $self->{fields}->{sysloglevel};
-			$self->{fields}->{sysloglevel} = 'debug';
-			carp " $el$location";
-			$self->{fields}->{sysloglevel} = $savedLogLevel;
-		}
-	}
-}
-
-
-
 42;
 
 
